package com.example.bookingapp_austinblanke;

import android.content.ContentValues;
import android.content.Context;
import android.database.Cursor;
import android.database.sqlite.SQLiteDatabase;
import android.database.sqlite.SQLiteOpenHelper;

import androidx.annotation.Nullable;

import java.util.ArrayList;


public class DatabaseConnector extends SQLiteOpenHelper {

    private static final String DB_NAME = "Registration.db";
    private static final int DB_VERSION = 1;
    private static final String TABLE_USERS = "Users";
    private static final String COLUMN_UID = "uid";
    private static final String COLUMN_USERNAME = "username";
    private static final String COLUMN_PASSWORD = "password";

    private static final String TABLE_PERFORMANCES = "performances";
    private static final String COLUMN_PERFORMANCEID = "performanceID";
    private static final String COLUMN_NAME = "name";
    private static final String COLUMN_DATE = "date";
    private static final String COLUMN_TIME = "time";
    private static final String COLUMN_VENUE = "venue";
    private static final String COLUMN_FLASH = "flash";
    private static final String COLUMN_WHEELCHAIR = "wheelchair";
    private static final String COLUMN_STEPS = "steps";
    private static final String COLUMN_TICSEAT = "ticSeat";
    private static final String COLUMN_TICSTAND = "ticStand";
    private static final String COLUMN_TICSTAGE = "ticStage";
    private static final String COLUMN_TICGRASS = "ticGrass";
    private static final String COLUMN_TICBOATA = "ticBoatA";
    private static final String COLUMN_TICBOATB = "ticBoatB";
    private static final String COLUMN_TICRIVERBANK = "ticRiverBank";
    private static final String COLUMN_TICINNERCIRCLE = "ticInnerCircle";
    private static final String COLUMN_TICOUTTERCIRCLE = "ticOutterCircle";


    public DatabaseConnector(Context context, SQLiteDatabase.CursorFactory factory) {
        super(context, DB_NAME, factory, DB_VERSION);
    }

    @Override
    public void onCreate(SQLiteDatabase db) {

        String CREATE_table1 = "CREATE TABLE " + TABLE_USERS + "(" +
                COLUMN_UID + " INTEGER PRIMARY KEY, " +
                COLUMN_USERNAME + " TEXT, " +
                COLUMN_PASSWORD + " TEXT)";
        db.execSQL(CREATE_table1);

        String CREATE_table2 = "CREATE TABLE " + TABLE_PERFORMANCES + "(" +
                COLUMN_PERFORMANCEID + " INTEGER PRIMARY KEY, " +
                COLUMN_NAME + " TEXT, " +
                COLUMN_DATE + " TEXT, " +
                COLUMN_TIME + " TEXT, " +
                COLUMN_VENUE + " TEXT, " +
                COLUMN_FLASH + " TEXT, " +
                COLUMN_WHEELCHAIR + " TEXT, " +
                COLUMN_STEPS + " TEXT, " +
                COLUMN_TICSEAT + " TEXT, " +
                COLUMN_TICSTAND + " TEXT, " +
                COLUMN_TICSTAGE + " TEXT, " +
                COLUMN_TICGRASS + " TEXT, " +
                COLUMN_TICBOATA + " TEXT, " +
                COLUMN_TICBOATB + " TEXT, " +
                COLUMN_TICRIVERBANK + " TEXT, " +
                COLUMN_TICINNERCIRCLE + " TEXT, " +
                COLUMN_TICOUTTERCIRCLE + " TEXT)";
        db.execSQL(CREATE_table2);

        ContentValues play1 = new ContentValues();
        play1.put(COLUMN_PERFORMANCEID, 1);
        play1.put(COLUMN_NAME, "The Merchant of Venice by William Shakespeare");
        play1.put(COLUMN_DATE, "Sunday April 23 2023");
        play1.put(COLUMN_TIME, "20:00");
        play1.put(COLUMN_VENUE, "Merchant Adventurer's Hall, York");
        play1.put(COLUMN_FLASH, "false");
        play1.put(COLUMN_WHEELCHAIR, "true");
        play1.put(COLUMN_STEPS, "false");
        play1.put(COLUMN_TICSEAT, "17,8");
        db.insert(TABLE_PERFORMANCES, null, play1);

        ContentValues play2 = new ContentValues();
        play2.put(COLUMN_PERFORMANCEID, 2);
        play2.put(COLUMN_NAME, "Hamlet by William Shakespeare");
        play2.put(COLUMN_DATE, "Friday 19 May 2023");
        play2.put(COLUMN_TIME, "18:00");
        play2.put(COLUMN_VENUE, "Clifford's Tower, York");
        play2.put(COLUMN_FLASH, "true");
        play2.put(COLUMN_WHEELCHAIR, "false");
        play2.put(COLUMN_STEPS, "true");
        play2.put(COLUMN_TICSEAT, "8,8");
        db.insert(TABLE_PERFORMANCES, null, play2);

        ContentValues play3 = new ContentValues();
        play3.put(COLUMN_PERFORMANCEID, 3);
        play3.put(COLUMN_NAME, "A Midsummer Night's Dream by William Shakespeare");
        play3.put(COLUMN_DATE, "Saturday 3 June 2023");
        play3.put(COLUMN_TIME, "19:00");
        play3.put(COLUMN_VENUE, "Dean's Park, York");
        play3.put(COLUMN_FLASH, "true");
        play3.put(COLUMN_WHEELCHAIR, "true");
        play3.put(COLUMN_STEPS, "false");
        play3.put(COLUMN_TICSTAGE, "11,4");
        play3.put(COLUMN_TICGRASS, "29,4");
        db.insert(TABLE_PERFORMANCES, null, play3);

        ContentValues play4 = new ContentValues();
        play4.put(COLUMN_PERFORMANCEID, 4);
        play4.put(COLUMN_NAME, "Oedipus the King by Sophocles");
        play4.put(COLUMN_DATE, "Friday 28 July");
        play4.put(COLUMN_TIME, "20:00");
        play4.put(COLUMN_VENUE, "St Mary's Abbey, Museum Gardens, York");
        play4.put(COLUMN_FLASH, "false");
        play4.put(COLUMN_WHEELCHAIR, "true");
        play4.put(COLUMN_STEPS, "false");
        play4.put(COLUMN_TICSEAT, "5,9");
        play4.put(COLUMN_TICSTAND, "12,7");
        db.insert(TABLE_PERFORMANCES, null, play4);

        ContentValues play5 = new ContentValues();
        play5.put(COLUMN_PERFORMANCEID, 5);
        play5.put(COLUMN_NAME, "The Tempest by William Shakespeare");
        play5.put(COLUMN_DATE, "Saturday 19 August");
        play5.put(COLUMN_TIME, "14:00");
        play5.put(COLUMN_VENUE, "Millennium Bridge, York");
        play5.put(COLUMN_FLASH, "false");
        play5.put(COLUMN_WHEELCHAIR, "true");
        play5.put(COLUMN_STEPS, "false");
        play5.put(COLUMN_TICBOATA, "6,9");
        play5.put(COLUMN_TICRIVERBANK, "10,7");
        db.insert(TABLE_PERFORMANCES, null, play5);

        ContentValues play6 = new ContentValues();
        play6.put(COLUMN_PERFORMANCEID, 6);
        play6.put(COLUMN_NAME, "Antigone by Sophocles");
        play6.put(COLUMN_DATE, "Thursday 20 September");
        play6.put(COLUMN_TIME, "21:00");
        play6.put(COLUMN_VENUE, "Crypt, York Minster, York");
        play6.put(COLUMN_FLASH, "false");
        play6.put(COLUMN_WHEELCHAIR, "false");
        play6.put(COLUMN_STEPS, "true");
        play6.put(COLUMN_TICINNERCIRCLE, "5,16");
        play6.put(COLUMN_TICOUTTERCIRCLE, "8,13");
        play6.put(COLUMN_TICSTAND, "10,10");
        db.insert(TABLE_PERFORMANCES, null, play6);

    }

    public void addNewUser(String username, String password) {
        ContentValues values = new ContentValues();
        values.put(COLUMN_USERNAME, username);
        values.put(COLUMN_PASSWORD, password);

        SQLiteDatabase db = this.getWritableDatabase();
        db.insert(TABLE_USERS, null, values);
        db.close();
    }

    @Override
    public void onUpgrade(SQLiteDatabase sqLiteDatabase, int i, int i1) {

    }

    public boolean usernameRepeat(String username) {
        boolean result = false;
        String query = "SELECT * FROM " + TABLE_USERS + " WHERE " + COLUMN_USERNAME + " = \"" + username + "\"";
        SQLiteDatabase db = this.getWritableDatabase();
        Cursor cursor = db.rawQuery(query, null);

        if (cursor.getCount() == 0) {
            result = false;
        } else result = true;


        cursor.close();
        db.close();

        return result;
    }

    public boolean login(String username, String password) {
        String query = "SELECT * FROM " + TABLE_USERS + " WHERE " + COLUMN_USERNAME + " = \"" + username + "\"";
        SQLiteDatabase db = this.getWritableDatabase();
        Cursor cursor = db.rawQuery(query, null);

        boolean result = false;

        if (cursor.moveToFirst()) {
            if (cursor.getString(2).equals(password))
                result = true;
            else
                result = false;
        }

        cursor.close();
        db.close();

        return result;
    }

    public ArrayList performanceTitles(boolean filter1, boolean filter2, boolean filter3) {

        ArrayList<String> performances = new ArrayList<>();
        String query = "SELECT * FROM " + TABLE_PERFORMANCES;
        SQLiteDatabase db = this.getWritableDatabase();
        Cursor cursor = db.rawQuery(query, null);
        cursor.moveToFirst();
        for(int i=0;i< cursor.getCount();i++){
            if (filter1 && filter2 && filter3)
                if(cursor.getString(5).equals("false") && cursor.getString(5).equals("true") && cursor.getString(5).equals("false")){
                                performances.add(cursor.getString(1));
            else{performances.add(cursor.getString(1));} //No filter present
            cursor.moveToNext();
        }

        //Close DB
        cursor.close();
        db.close();

        return performances;
    }

}